@@ -1692,7 +1692,7 @@ class Update(MethodsInterface):
                     _("Binary packages on the current binhost {} "
                       "are older than local").format(binhost_url))
             elif not ignore_level and not self.is_binhost_level_valid(binhost):
-                if self.compare_update_level(binhost.level) > 0:
+                if binhost.level and self.compare_update_level(binhost.level) > 0:
                     self.set_migration_mode(True)
                 raise UpdateError((
                     _("Current binhost {} has wrong update level. Current level: {} Binhost level: {}").\
