@@ -503,7 +503,15 @@ class ClUpdateAction(Action):
         {'name': 'success_rev',
          'message': __("System update finished!"),
          'condition': lambda Get: (Get('cl_update_rev_set') == 'on' and
-                                    Get('cl_update_pretend_set') == 'off')
+                                    Get('cl_update_pretend_set') == 'off' and
+                                    Get('cl_update_sync_only_set') == 'off')
+         },
+        # сообщение удачного завершения при обновлении ревизии
+        {'name': 'success_sync_only',
+         'message': __("System sync finished!"),
+         'condition': lambda Get: (Get('cl_update_rev_set') == 'on' and
+                                    Get('cl_update_pretend_set') == 'off' and
+                                    Get('cl_update_sync_only_set') == 'on')
          },
         # сообщение удачного завершения при пересоздании world
         {'name': 'success_world',
